==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/config/appconfiggroupwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "appconfiggroupwidget.h"

#include <qlayout.h>
#include <qbuttongroup.h>
#include <qgroupbox.h>

using namespace SubtitleComposer;

AppConfigGroupWidget::AppConfigGroupWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	QWidget( parent, 0, 0 ),
	m_configGroup( configGroup )
{
	m_mainLayout = new QGridLayout( this );
	m_mainLayout->setAlignment( Qt::AlignTop );
	m_mainLayout->setMargin( 0 );
	m_mainLayout->setSpacing( 5 );
}

AppConfigGroupWidget::~AppConfigGroupWidget()
{
}

const AppConfigGroup& AppConfigGroupWidget::configGroup()
{
	setConfigFromControls();
	return m_configGroup;
}

void AppConfigGroupWidget::setConfigGroup( const AppConfigGroup& configGroup )
{
	if ( m_configGroup.isCompatibleWith( configGroup ) )
	{
		m_configGroup = configGroup;
		setControlsFromConfig();
	}
}

void AppConfigGroupWidget::setControlsFromDefaults()
{
	m_configGroup.loadDefaults();
	setControlsFromConfig();
}

QButtonGroup* AppConfigGroupWidget::createButtonGroup( const QString& title, bool addToLayout )
{
	QButtonGroup* buttonGroup = new QButtonGroup( this );
	buttonGroup->setTitle( title );
	buttonGroup->setColumnLayout( 0, Qt::Vertical );
	buttonGroup->layout()->setSpacing( 5 );

	if ( addToLayout )
		m_mainLayout->addWidget( buttonGroup, m_mainLayout->numRows(), 0 );

	return buttonGroup;
}

QGroupBox* AppConfigGroupWidget::createGroupBox( const QString& title, bool addToLayout )
{
	QGroupBox* groupBox = new QGroupBox( this );
	groupBox->setTitle( title );
	groupBox->setColumnLayout( 0, Qt::Vertical );
	groupBox->layout()->setSpacing( 5 );

	if ( addToLayout )
		m_mainLayout->addWidget( groupBox, m_mainLayout->numRows(), 0 );

	return groupBox;
}

QGridLayout* AppConfigGroupWidget::createGridLayout( QGroupBox* groupBox )
{
	QGridLayout* gridLayout = new QGridLayout( groupBox->layout() );
	gridLayout->setAlignment( Qt::AlignTop );
	return gridLayout;
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/config/appconfiggroupwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "appconfiggroupwidget.h"

#include <qlayout.h>
#include <qbuttongroup.h>

using namespace SubtitleComposer;

AppConfigGroupWidget::AppConfigGroupWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	QWidget( parent, 0, 0 ),
	m_configGroup( configGroup )
{
	m_mainLayout = new QGridLayout( this );
	m_mainLayout->setAlignment( Qt::AlignTop );
	m_mainLayout->setMargin( 0 );
	m_mainLayout->setSpacing( 5 );
}

AppConfigGroupWidget::~AppConfigGroupWidget()
{
}

const AppConfigGroup& AppConfigGroupWidget::configGroup()
{
	setConfigFromControls();
	return m_configGroup;
}

void AppConfigGroupWidget::setConfigGroup( const AppConfigGroup& configGroup )
{
	if ( m_configGroup.isCompatibleWith( configGroup ) )
	{
		m_configGroup = configGroup;
		setControlsFromConfig();
	}
}

void AppConfigGroupWidget::setControlsFromDefaults()
{
	m_configGroup.loadDefaults();
	setControlsFromConfig();
}

QButtonGroup* AppConfigGroupWidget::createButtonGroup( const QString& title, bool addToLayout )
{
	QButtonGroup* buttonGroup = new QButtonGroup( this );
	buttonGroup->setTitle( title );
	buttonGroup->setColumnLayout( 0, Qt::Vertical );
	buttonGroup->layout()->setSpacing( 5 );

	if ( addToLayout )
		m_mainLayout->addWidget( buttonGroup, m_mainLayout->numRows(), 0 );

	return buttonGroup;
}

QGridLayout* AppConfigGroupWidget::createGridLayout( QButtonGroup* buttonGroup )
{
	QGridLayout* gridLayout = new QGridLayout( buttonGroup->layout() );
	gridLayout->setAlignment( Qt::AlignTop );
	return gridLayout;
}
